.. _api-managers:

========
Managers
========

.. automodule:: projector.managers

Return to :ref:`api`.

.. manager:: ProjectManager

ProjectManager
==============

.. autoclass:: projector.managers.ProjectManager
   :members:

